@@ -1,6 +1,7 @@
 #' @title Summarize output of cluster bootstrap GLM
 #' @description Returns the summary of an object of class \code{clusbootglm}.
 #' @param object object of class \code{clusbootglm}.
+#' @param estimate.type specify which type of estimate should be returned, either bootstrap means (default) or GLM estimates from model fitted on original data.
 #' @param interval.type which confidence interval should be used. Options are \code{parametric}, \code{percentile}, and \code{BCa} intervals.
 #' @param ... other arguments.
 #' @author Mathijs Deen
@@ -9,18 +10,30 @@
 #' cbglm.1 <- clusbootglm(SCORE~Time*COG,data=opposites,clusterid=Subject)
 #' summary(cbglm.1, interval.type="percentile")}
 #' @export
-summary.clusbootglm<-function(object,interval.type="BCa",...){
+summary.clusbootglm<-function(object,estimate.type="bootstrap",interval.type="BCa",...){
   model <- object
   ci.boundaries <- c((1-model$ci.level)/2,1-(1-model$ci.level)/2)
   cat(sprintf("\nCall:\n"))
   print(model$call)
   cat(sprintf("\n"))
-  ifelse(interval.type=="BCa", confinttab <- model$BCa.interval, ifelse(interval.type=="parametric", confinttab <- model$parametric.interval, confinttab <- model$percentile.interval))
-  tabel <- cbind(model$lm.coefs,model$boot.sds,confinttab)
-  dimnames(tabel)[[2]]<-c('Est. (GLM)','SE (Bootstrap)',sprintf('CI %.1f%%',100*ci.boundaries[1]),sprintf('CI %.1f%%',100*ci.boundaries[2]))
+  ifelse(estimate.type=="GLM",
+         coefs <- model$lm.coefs,
+         coefs <- model$boot.coefs)
+  ifelse(interval.type=="percentile", 
+         confinttab <- model$percentile.interval, 
+         ifelse(interval.type=="parametric", 
+                confinttab <- model$parametric.interval, 
+                confinttab <- model$BCa.interval))
+  tabel <- cbind(coefs,model$boot.sds,confinttab)
+  dimnames(tabel)[[2]]<-c('Estimate','Std.error',sprintf('CI %.1f%%',100*ci.boundaries[1]),sprintf('CI %.1f%%',100*ci.boundaries[2]))
   print(tabel)
   cat(sprintf("---\n"))
-  cat(paste(100*model$ci.level,"% confidence interval using ", ifelse(interval.type=="BCa", "bias corrected and accelerated", ifelse(interval.type=="parametric", "parametric", "percentile")), " cluster bootstrap intervals", sep=""))
+  cat(paste(100*model$ci.level,"% confidence interval using ", ifelse(interval.type=="percentile", 
+                                                                      "percentile", 
+                                                                      ifelse(interval.type=="parametric", 
+                                                                             "parametric", 
+                                                                             "bias corrected and accelerated")), 
+            " cluster bootstrap intervals", sep=""))
   failed.samples.n <- sum(model$failed.bootstrap.samples)
   if(failed.samples.n>0){
     cat(sprintf("\nThere were %d bootstrap samples which returned at least one NA", sum(is.na(rowSums(model$coefficients)))))
